package main

import (
	"flag"
	"fmt"
	"log"

	"github.com/go-sql-driver/mysql"
	"gitlab.celogeek.com/photos/api/internal/env"
	"gitlab.celogeek.com/photos/api/internal/photos/api"
)

var (
	genv                = env.New()
	listen              = fmt.Sprintf("%s:%d", genv.Get("LISTEN_HOST", "[::]"), genv.GetUInt("LISTEN_PORT", 8000))
	mysqlAddr           = fmt.Sprintf("%s:%d", genv.Get("MYSQL_HOST", "localhost"), genv.GetUInt("MYSQL_PORT", 3306))
	mysqlUser           = genv.Get("MYSQL_USER", "photos")
	mysqlPassword       = genv.Get("MYSQL_PASSWD", "photos")
	mysqlDatabase       = genv.Get("MYSQL_DB", "photos")
	getEnvConfig        = false
	getCurrentEnvConfig = false
	storePath           = genv.Get("STORE_PATH", "./data")
)

func main() {
	config := &api.ServiceConfig{
		DB: mysql.NewConfig(),
	}

	flag.StringVar(&config.Listen, "listen", listen, "Listen address")
	flag.StringVar(&config.DB.Addr, "mysql-addr", mysqlAddr, "Mysql addr")
	flag.StringVar(&config.DB.User, "mysql-user", mysqlUser, "Mysql user")
	flag.StringVar(&config.DB.Passwd, "mysql-password", mysqlPassword, "Mysql password")
	flag.StringVar(&config.DB.DBName, "mysql-database", mysqlDatabase, "Mysql database")
	flag.BoolVar(&getEnvConfig, "generate-config", false, "Generate an env config")
	flag.BoolVar(&getCurrentEnvConfig, "generate-current-config", false, "Generate an env config with current env")
	flag.StringVar(&config.StorePath, "file-path", storePath, "Store path for the files")
	flag.Parse()

	if getEnvConfig {
		for _, r := range genv.Fallback() {
			fmt.Printf("%s=%q\n", r.Key, r.Value)
		}
		return
	}

	if getCurrentEnvConfig {
		for _, r := range genv.Current() {
			fmt.Printf("%s=%q\n", r.Key, r.Value)
		}
		return
	}

	p := api.New(config)

	if err := p.Run(); err != nil {
		log.Fatal(err)
	}

}
